<p align="center">
<img src="https://github.com/MarcG-LBMC-Lyos/QCTMA/blob/main/imgs/Illustration.jpg?raw=true">
</p>
Injects material (Young's modulus) to each element, based on a Dicom stack, and gray level to Young's modulus relationships. Specifically designed to be used with Ansys .cdb meshes.

## Installation
```bash
pip install .  # In the root folder of the repository
# or
pip install QCTMA  # In any folder (will install the latest version from Pypi)
```

## Usage
Check the quickstart_QCTMA.py file (in Utility_scripts directory) for an example of usage.\
Check the display_QCTMA.py file (in Utility_scripts directory) for an example of display of the results.